@@ -8,7 +8,7 @@ use strict;
 use autodie;
 use Carp;
 
-use version; our $VERSION = qv('0.9.2');
+use version; our $VERSION = qv('0.9.3');
 
 use File::Which qw(which);
 use Path::Tiny qw(path cwd);
@@ -339,6 +339,7 @@ sub _dsn_hash_to_dsn_string {
 
 }
 
+
 ## pgpass functions
 sub _parse_pgpass {
 
@@ -814,7 +815,7 @@ App::CatalystStarter::Bloated - Creates a catalyst app, a TT view, a model and a
 
 =head1 VERSION
 
-This document describes App::CatalystStarter::Bloated version 0.9.2
+This document describes App::CatalystStarter::Bloated version 0.9.3
 
 =head1 SYNOPSIS
 
@@ -879,27 +880,10 @@ Several. Makefile/Build should take care of them.
 
 =head1 INCOMPATIBILITIES
 
-=for author to fill in:
-    A list of any modules that this module cannot be used in conjunction
-    with. This may be due to name conflicts in the interface, or
-    competition for system or program resources, or due to internal
-    limitations of Perl (for example, many modules that use source code
-    filters are mutually incompatible).
-
 None reported.
 
-
 =head1 BUGS AND LIMITATIONS
 
-=for author to fill in:
-    A list of known problems with the module, together with some
-    indication Whether they are likely to be fixed in an upcoming
-    release. Also a list of restrictions on the features the module
-    does provide: data types that cannot be handled, performance issues
-    and the circumstances in which they may arise, practical
-    limitations on the size of data sets, special cases that are not
-    (yet) handled, etc.
-
 No bugs have been reported.
 
 Please report any bugs or feature requests to
